% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/exportar.R
\name{svySE_xlsx}
\alias{svySE_xlsx}
\title{Export svySE results to '.xlsx' files}
\usage{
svySE_xlsx(
  x,
  select = NULL,
  file_err = NULL,
  file_tab = NULL,
  cols_err = svySE_cols_err("full"),
  cols_tab = svySE_cols_tab("full"),
  start_row = 10,
  overwrite = TRUE,
  keep_na = FALSE
)
}
\arguments{
\item{x}{Objeto generado por \code{svySE_calc()} o \code{svySE_simple()}, o una lista
nombrada que contenga varios objetos de estas clases.
Object generated by \code{svySE_calc()} or \code{svySE_simple()}, or a named list
containing multiple objects of these classes.}

\item{select}{Vector de texto opcional con los nombres de los elementos de
\code{x} que se desean exportar. Solo se utiliza cuando \code{x} es una lista de
resultados. Si es \code{NULL}, se exportan todos.
Optional character vector containing the names of the elements in \code{x} to
export. It is only used when \code{x} is a list of results. If \code{NULL}, all
results are exported.}

\item{file_err}{Ruta del archivo \code{.xlsx} para exportar las tablas de errores
muestrales. Si es \code{NULL}, no se exportan.
Path to the \code{.xlsx} file used to export sampling error tables. If \code{NULL},
they are not exported.}

\item{file_tab}{Ruta del archivo \code{.xlsx} para exportar las tablas simples.
Si es \code{NULL}, no se exportan.
Path to the \code{.xlsx} file used to export simple tables. If \code{NULL}, they are
not exported.}

\item{cols_err}{Columnas de error a exportar.
Sampling error columns to export.}

\item{cols_tab}{Columnas de tabla simple a exportar.
Simple table columns to export.}

\item{start_row}{Fila inicial de escritura.
Starting row for writing.}

\item{overwrite}{Sobrescribir archivos existentes.
Whether existing files should be overwritten.}

\item{keep_na}{Mantener \code{NA} en el archivo exportado.
Whether \code{NA} values should be preserved in the exported file.}
}
\value{
Invisiblemente una lista con las rutas de los archivos exportados y
los resultados seleccionados.
Invisibly returns a list containing the exported file paths and selected
result names.
}
\description{
Exporta uno o varios resultados generados por \code{svySE_calc()} y
\code{svySE_simple()} a archivos \code{.xlsx}.
}
\details{
Exports one or more results generated by \code{svySE_calc()} and
\code{svySE_simple()} to \code{.xlsx} files.

Debe especificarse al menos uno de \code{file_err} o \code{file_tab}.

Cuando \code{x} es una lista, sus elementos deben tener nombres unicos. Los
objetos de clase \code{"svySE_result"} se exportan a \code{file_err}, mientras que los
objetos de clase \code{"svySE_simple_result"} se exportan a \code{file_tab}.

At least one of \code{file_err} or \code{file_tab} must be provided.

When \code{x} is a list, its elements must have unique names. Objects of class
\code{"svySE_result"} are exported to \code{file_err}, while objects of class
\code{"svySE_simple_result"} are exported to \code{file_tab}.
}
