% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/columnas.R
\name{svySE_chk_cols}
\alias{svySE_chk_cols}
\title{Check selected columns}
\usage{
svySE_chk_cols(cols, all_cols, arg = "cols")
}
\arguments{
\item{cols}{Columnas seleccionadas / Selected columns.}

\item{all_cols}{Columnas disponibles / Available columns.}

\item{arg}{Nombre del argumento / Argument name.}
}
\value{
Invisiblemente \code{TRUE}.
}
\description{
Valida que las columnas seleccionadas existan dentro del conjunto permitido.
Checks whether selected columns exist in the allowed column set.
}
\keyword{internal}
